@@ -34,19 +34,19 @@ lazy_static! {
 
 fn store_type(item: &IgniteTypeDefinition) {
     #[cfg(feature = "target-yaml")]
-    store_type_yaml(&item);
+    store_type_yaml(item);
     #[cfg(feature = "target-json")]
-    store_type_json(&item);
+    store_type_json(item);
     #[cfg(feature = "target-ron")]
-    store_type_ron(&item);
+    store_type_ron(item);
     #[cfg(feature = "target-binary")]
-    store_type_binary(&item);
+    store_type_binary(item);
 }
 
 #[cfg(feature = "target-yaml")]
 fn store_type_yaml(item: &IgniteTypeDefinition) {
     let name = match &item.variant {
-        IgniteTypeVariant::StructUnit(item) => &item,
+        IgniteTypeVariant::StructUnit(item) => item,
         IgniteTypeVariant::StructNamed(item) => &item.name,
         IgniteTypeVariant::StructUnnamed(item) => &item.name,
         IgniteTypeVariant::Enum(item) => &item.name,
